pub struct AesNonExpanded(/* private fields */);Expand description
Circuit for AES-128 without key expansion.
For an input (key, block), output AES-128(key, block).
Implementations
Sourceimpl AesNonExpanded
impl AesNonExpanded
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new AesNonExpanded circuit.
Performance Note!
This involves parsing a Bristol Format file, and thus is not cheap! Hence,
it is best to reuse this circuit if possible versus calling
AesNonExpanded::new every time this circuit is needed.